@@ -12,7 +12,7 @@ namespace turbodbc {
  * @brief This type represents a single field in a table, i.e., the data associated
  *        with a given row and column
  */
-using field = boost::variant<	long,
+using field = boost::variant<	int64_t,
 								std::string,
 								bool,
 								double,
