@@ -1,15 +1,3 @@
-/**
- *  @file connection.cpp
- *  @date 16.05.2014
- *  @author mkoenig
- *  @brief 
- *
- *  $LastChangedDate: 2014-05-16 13:39:31 +0200 (Fr, 16 Mai 2014) $
- *  $LastChangedBy: mkoenig $
- *  $LastChangedRevision: 19531 $
- *
- */
-
 #include "cpp_odbc/connection.h"
 
 namespace cpp_odbc {
@@ -22,7 +10,7 @@ std::shared_ptr<statement const> connection::make_statement() const
 	return do_make_statement();
 }
 
-void connection::set_attribute(SQLINTEGER attribute, long value) const
+void connection::set_attribute(SQLINTEGER attribute, intptr_t value) const
 {
 	do_set_attribute(attribute, value);
 }
@@ -47,4 +35,9 @@ SQLUINTEGER connection::get_integer_info(SQLUSMALLINT info_type) const
 	return do_get_integer_info(info_type);
 }
 
+bool connection::supports_function(SQLUSMALLINT function_id) const
+{
+	return do_supports_function(function_id);
+}
+
 }
