@@ -22,15 +22,15 @@ namespace cpp_odbc {
 
 std::shared_ptr<environment> make_environment()
 {
-	auto level1_api = std::make_shared<level1::unixodbc_backend const>();
-	auto level2_api = std::make_shared<level2::level1_connector const>(level1_api);
+	auto level1_api = std::make_shared<level1::unixodbc_backend>();
+	auto level2_api = std::make_shared<level2::level1_connector>(level1_api);
 	return std::make_shared<level3::raii_environment>(level2_api);
 }
 
 std::shared_ptr<environment> make_debug_environment()
 {
-	auto level1_api = std::make_shared<level1::unixodbc_backend_debug const>();
-	auto level2_api = std::make_shared<level2::level1_connector const>(level1_api);
+	auto level1_api = std::make_shared<level1::unixodbc_backend_debug>();
+	auto level2_api = std::make_shared<level2::level1_connector>(level1_api);
 	return std::make_shared<level3::raii_environment>(level2_api);
 }
 
