@@ -31,9 +31,9 @@ SQLSMALLINT description::column_sql_type() const
 	return do_column_sql_type();
 }
 
-void description::set_field(cpp_odbc::writable_buffer_element & element, field const & value) const
+SQLSMALLINT description::digits() const
 {
-	do_set_field(element, value);
+	return do_digits();
 }
 
 type_code description::get_type_code() const
