@@ -31,11 +31,9 @@ SQLSMALLINT floating_point_description::do_column_sql_type() const
 	return SQL_DOUBLE;
 }
 
-void floating_point_description::do_set_field(cpp_odbc::writable_buffer_element & element, field const & value) const
+SQLSMALLINT floating_point_description::do_digits() const
 {
-	auto const as_double = boost::get<double>(value);
-	memcpy(element.data_pointer, &as_double, element_size());
-	element.indicator = element_size();
+	return 0;
 }
 
 type_code floating_point_description::do_get_type_code() const
